Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1563)

Unified Diff: src/platform.h

Issue 18094: Fix a bunch of spelling mistakes :\ (Closed)
Patch Set: More fixes. Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/parser.cc ('k') | src/platform-macos.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/platform.h
diff --git a/src/platform.h b/src/platform.h
index 8d62efdea13cf49f2f5ac6e7f7e2b2bc2e137cde..0e42ba66f443267fe5da8b7c01601fe84406f2ee 100644
--- a/src/platform.h
+++ b/src/platform.h
@@ -33,7 +33,7 @@
// implementation for a particular platform is put in platform_<os>.cc.
// The build system then uses the implementation for the target platform.
//
-// This design has been choosen because it is simple and fast. Alternatively,
+// This design has been chosen because it is simple and fast. Alternatively,
// the platform dependent classes could have been implemented using abstract
// superclasses with virtual methods and having specializations for each
// platform. This design was rejected because it was more complicated and
@@ -145,7 +145,7 @@ class OS {
static void PrintError(const char* format, ...);
static void VPrintError(const char* format, va_list args);
- // Allocate/Free memory used by JS heap. Pages are readable/writeable, but
+ // Allocate/Free memory used by JS heap. Pages are readable/writable, but
// they are not guaranteed to be executable unless 'executable' is true.
// Returns the address of allocated memory, or NULL if failed.
static void* Allocate(const size_t requested,
@@ -162,8 +162,8 @@ class OS {
// heap corruption.
static bool IsOutsideAllocatedSpace(void* pointer);
- // Sleep for a number of miliseconds.
- static void Sleep(const int miliseconds);
+ // Sleep for a number of milliseconds.
+ static void Sleep(const int milliseconds);
// Abort the current process.
static void Abort();
« no previous file with comments | « src/parser.cc ('k') | src/platform-macos.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698